| scAnnotator | R Documentation |
Automatic annotation of cell types
scAnnotator(
query.obj,
group.by = "seurat_clusters",
method = c("seurat"),
ref.data = NULL,
ref.ann = NULL,
markers = NULL,
plot = TRUE,
outdir = "./"
)
query.obj |
A seurat object for cell type annotation. |
group.by |
A character specifying the cluster column in meta.data. |
method |
A vector specifying the cell type annotation methods. Should be one of singler, sclearn, scmap-cell, scmap-cluster, seurat |
ref.data |
A matrix like object specifying the reference data or a Seurat object. |
ref.ann |
A vector specifying the cell type annotation of the reference data. |
markers |
A list with Positive (markers$Positive) and Negative markers (markers$Negative) of cell types. |
plot |
A boolean indicating whether to save and visualize the prediction results. |
outdir |
Path to the output directory. |
A seurat object with prediction results added into meta.data.
Wubing Zhang
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.